"""Pyupgrade formatter management."""
from python_dev_tools.formatters.common import Formatter


class PyupgradeFormatter(Formatter):
    """Pyupgrade formatter management."""

    name = "pyupgrade"
    path = "pyupgrade"
    cli_args = ["--py37-plus"]
